@@ -11,8 +11,8 @@ class Model:
         self._parse_model_uri(model_uri)
 
         self.inference_client = get_inference_client(
+            org_name=self.org_name,
             model_name=self.model_name,
-            project_name=self.project_name,
             model_version_name=self.model_version_name,
         )
 
@@ -21,14 +21,14 @@ class Model:
         if not m:
             raise InvalidModelURI("invalid_model_route")
 
-        project_name = m.group(1)
+        org_name = m.group(1)
         model_name = m.group(2)
         model_version_name = m.group(3)
 
         if model_version_name == "":
             model_version_name = None
 
-        self.project_name = project_name
+        self.org_name = org_name
         self.model_name = model_name
         self.model_version_name = model_version_name
 
