@@ -177,7 +177,7 @@ class BinaryType(ModelTypeSerializer):
         pass
 
     def schema(self):
-        return {}
+        return {"type": "binary"}
 
     def serialize(self, obj):
         try:
